extensions [ gis ]

breed [agents agent]

globals 
[ 
  elevation-dataset 
  max-elev 
  nummap
]

agents-own
[
  trait
  pop
  aforesight
  acopyrate
  fsdist
]

patches-own 
[ 
  elevation
  currentelev 
  timestamp
  occfreq
  cum-effit
]

; SETUP CODE ###############################################################################################################

to setup
  ;random-seed 1
  ca
  set nummap 0
  if first fmap = "2"
  [
    gis:load-coordinate-system (word "surfeq/surf.prj")
    set elevation-dataset gis:load-dataset (word "surfeq/" fmap "/" run# ".asc")
    gis:set-world-envelope (gis:envelope-of elevation-dataset)
    set nummap read-from-string fmap
  ]
  if fmap = "cone"
  [
    gis:load-coordinate-system (word "surfeq/surf.prj")
    set elevation-dataset gis:load-dataset (word "surfeq/" fmap "/" run# ".asc")
    gis:set-world-envelope (gis:envelope-of elevation-dataset)
  ]
  gis:apply-raster elevation-dataset elevation
  display-elevation
  set max-elev gis:maximum-of elevation-dataset
  
  create-agents N
  [
    ifelse colonize? = TRUE [ ;begin with agents distributed around one corner
      setxy max-pxcor - round(abs(random-normal 0 10)) max-pycor - round(abs(random-normal 0 10)) 
      while [ elevation < 0 OR count agents-here > 1 ] [ 
        setxy max-pxcor - round(abs(random-normal 0 10)) max-pycor - round(abs(random-normal 0 10)) 
      ]
    ]
    [;else random placement
      setxy round random-xcor round random-ycor
      while [ elevation <= 0 OR count agents-here > 1] [ setxy round random-xcor round random-ycor ]
    ]
    
    ifelse randTrait? = false  ;set all trait values to same value, as specified by interface slider
    [ 
      if mode = "info" [set acopyrate copyrate color-gradient acopyrate]
      if mode = "radius" [set fsdist 1 color-gradient ( fsdist / 2 )]
    ]
    [;else randTrait? = true, assign random trait value
      if mode = "info" [set acopyrate random-float 1 color-gradient acopyrate]
      if mode = "radius" [
        set fsdist 1 + plus-or-minus mutation-size
        if fsdist < 0 [set fsdist 0]
        color-gradient ( fsdist / 2 ) 
      ]
    ];close randTrait?
    
    set aforesight foresight ; I retain the original term for resource assessment accuracy, foresight, within the model code
  ]; close agents
  
  ;;; for quantifying reproductive potential (cumulative reproductive fitness) more comments in go code
  ;  ask patches [set timestamp 0 set occfreq 0 set currentelev elevation ] 
  ask patches [set cum-effit 0]
  reset-ticks
end

; GO CODE ###############################################################################################################

to go 
  if (mode = "info") ;set run type to information sharing
  [
    go-info
  ]
  if (mode = "radius") ;set run type to assessment radius 
  [
    go-radius 
  ]

  if not any? agents [stop]
  
  tick 
end

to go-radius
  let maxfit max [elevation] of agents + 1 ; addition protects against crash by div zero
  let maxdist max [fsdist] of agents + 0.001
  ask agents
  [
    let birth-adjust ( elevation / maxfit ) * birth-rate ;differential reproduction, decreases probability of reproduction for agents with low resources
    if (random-float 1 < birth-adjust) [
        hatch 1 [
          if (random-float 1 < mutation-rate) [ ;at the specified rate, change parent's trait value by mutation-size, otherwise inhereit parent's value
            set fsdist fsdist + plus-or-minus mutation-size
            if fsdist < 0 [set fsdist 0]
            color-gradient ( fsdist / maxdist )
          ] ;close mutation-rate
    
            ;;;;;;;; drop offspring on any empy neighbouring cell, or die if all are full
            let p one-of neighbors with [not any? agents-here = TRUE]
            ifelse (p != nobody) [
              move-to p
              if death-rate = 0 [ask one-of agents [die]] ;if population size is fixed
            ][;else p=nobody
              die
            ]
          
        ] ;close hatch 
    ];close birth-adjust

    ;;;;;;;;; mobility 
    ifelse (random-float 1 < aforesight)
    [;hill-climb if foresight correct
      let p max-one-of patches in-radius fsdist [elevation] ;choose best cell within assessment radius
      if (p != patch-here) 
      [
        face p
        if not any? agents-on patch-ahead 1 [ move-to patch-ahead 1 ] ;move towards it if there is an empty cell
      ]

    ]
    [;else random movement if foresight wrong (inaccurate assessment)
      let p one-of neighbors 
      if not any? agents-on p [ move-to p ]
    ]

    if death-rate > 0 [ ;for variable population size, kill of random agents at specified probability
      if (random-float 1 < death-rate) [die]
    ];close death
  ];close ask agents
  
  ;;;; Commented out code below used for quantifying the cumulative effective fitness (reproductive availability) of cells during a run. 
  ;;;; Too compuatationally expensive to leave running all the time
  ;  let effit 0   
  ;  ask patches
  ;  [
  ;    if timestamp = 0 AND any? agents-here = TRUE [set timestamp ticks ]
  ;    if timestamp > 0 AND any? agents-here = TRUE [set occfreq occfreq + count agents-here]
  ;    let basefit ( elevation / maxfit * birth-rate) 
  ;    ifelse (count agents-on neighbors < 8) [set effit basefit][set effit 0]
  ;    set cum-effit cum-effit + effit
  ;  ]
  
  if ticks mod 100 = 0 AND count agents > 2 [ ;plotting
    let fsdist_med median [fsdist] of agents
    set-current-plot "Trait"
    set-current-plot-pen "Median" 
    plotxy ticks fsdist_med
  ]
end

to go-info ;go code for information sharing model, comments from above generally apply
  let maxfit max [elevation] of agents + 1 ; addition protects against crash by div zero
  ask agents
  [
    let birth-adjust ( elevation / maxfit ) * birth-rate
    if (random-float 1 < birth-adjust) [
      hatch 1 [
        if (random-float 1 < mutation-rate) [
          set acopyrate acopyrate + plus-or-minus mutation-size ;mutation
          if acopyrate > 1 [set acopyrate 1]
          if acopyrate < 0 [set acopyrate 0]
          color-gradient acopyrate
        ] ;close mutation-rate
 
        ;random drop hatching
        let p one-of neighbors with [not any? agents-here = TRUE]
        ifelse (p != nobody) [
          move-to p
          if death-rate = 0 [ask one-of agents [die]]
        ][;else p=nobody
          die
        ]
      ] ;close hatch 
    ];close birthadjust
         
    ;Movement
    ifelse random-float 1 < acopyrate [ ;inherited probability of copying another agent vs exploration
      let a one-of other agents ;randomly pick a target agent from population
      if (a != nobody AND [elevation] of a > elevation) [ ; if target's resource value is higher than the agent's, then try to move
        face a  
        if not any? agents-on patch-ahead 1 [move-to patch-ahead 1] ;step towards if there is an empty cell 
      ]
    ]
    [;else: move randomly if chose not to copy / copy error 
      let p one-of neighbors
      if not any? agents-on p [move-to p]
    ];close acopyrate
 
    if death-rate > 0 [
      if (random-float 1 < death-rate) 
      [
        die
      ]
    ];close death
  ];close ask agents
  if not any? agents [stop]

;  let effit 0
;  ask patches
;  [
;    if timestamp = 0 [if any? agents-here = TRUE [set timestamp ticks]]
;    if timestamp > 0 AND any? agents-here = TRUE [set occfreq occfreq + count agents-here]
;    let basefit ( elevation / maxfit * birth-rate) 
;    ifelse (count agents-on neighbors < 8) [set effit basefit][set effit 0]
;    set cum-effit cum-effit + effit
;  ]
  
  
  if ticks mod 100 = 0 [
  ;if plots-on? = TRUE [
    let cp_med median [acopyrate] of agents
    set-current-plot "Trait"
    set-current-plot-pen "Median" 
    plotxy ticks cp_med
  ]
end


;DISPLAY MODULES ###############################################################################################################

to display-ticks ;mapping the pattern of initial occupation, not used in article
  ask agents [set hidden? true]
  ask patches
  [
    if (timestamp > 0)
    [
      set pcolor scale-color red timestamp 0 ticks
    ]
  ]
end

to display-occfreq ;mapping the cumulative occupation history of each cell, not used in article
  let max-occfreq max [occfreq] of patches
  ask agents [set hidden? true]
  ask patches
  [
    if (occfreq > 0)
    [
      set pcolor scale-color red occfreq 0 max-occfreq
    ]
  ]
end

to display-elevation ;display landscape code borrowed from GIS code example, elevation represents the resource value
  let min-elevation gis:minimum-of elevation-dataset
  let max-elevation gis:maximum-of elevation-dataset
  
  ask patches
  [ ; 
    set pcolor 99
    if (elevation > 0) [set pcolor scale-color black elevation min-elevation max-elevation ] 
  ]
  ask agents [set hidden? false]
end


to display-effit
  ;init set cum-effit 0 in setup
  ;add cum-effit to patches-own
  ;add to maptype chooser
  ;add display to go
  ;let effit 0
  ;let maxfit max [elevation] of agents + 1
  let max-cum-effit max [cum-effit] of patches
  ask agents [set hidden? true]
  ask patches
  [
  ;  let basefit ( elevation / maxfit ) 
  ;  ifelse (count agents-on neighbors < 8) [set effit basefit][set effit 0]
  ;  set cum-effit cum-effit + effit
    set pcolor scale-color green cum-effit 0 max-cum-effit 
  ]
end

;HELPER MODULES ###############################################################################################################

to export-map [folder] ;this section is a bit sloppy. Exports a raster of the cumulative occupation history, a proxy for the archaeological record. Not used in article.
  ;** Create raster dataset 
  let occraster gis:create-raster world-width world-height gis:world-envelope 
  ;** Transfer agent's trait value of each netlogo patch to the occraster layer 
  set occraster gis:patch-dataset occfreq 
  
  ;** At last store the data in file 
  ;gis:store-dataset occraster (word "occraster/" nummap "_" run# "_f" round (foresight * 100) ".asc") 
;  ifelse (mode = "infoshare")
;  [
;    gis:store-dataset occraster (word folder remove "f" fmap "_" run# "_cr" round (copyrate * 100) "_f" round (foresight * 100) ".asc") 
;    gis:store-dataset occraster (word "infoshare/occraster/uh/" remove "f" fmap "_" run# "_cr" round (copyrate * 100) ".asc") 
;    gis:store-dataset occraster (word "infoshare/occraster/br/" remove "f" fmap "_" run# "_cr" round (copyrate * 100) ".asc") 
;  ]
;  [;else
    ;gis:store-dataset occraster (word "occraster/" remove "f" fmap "_" run# "_f" round (foresight * 100) ".asc") 
    ;gis:store-dataset occraster (word folder "/" fmap "_" run# "m_" mutation-size ".asc") 
    gis:store-dataset occraster (word folder "/" fmap "_" run# "br_" birth-rate ".asc") 
;  ]
;  gis:store-dataset occraster (word "occraster/" fmap "_f" round (foresight * 100) ".asc") 
  ;(word "occraster/" fmap "/" colonize? "/" "f" round (foresight * 100) ".png")
end

to screenshots ;export series of images during a run
  if ticks mod 10 = 0
  [
    export-view (word "screenshots/" fmap "/ticks/img" round (ticks / 10) ".png") 
  ]
end

to color-gradient [number] ;agent colour-scheme, creates a bi-polar colour gradient from dark red through white through dark blue
  ;ifelse (number < 0.5) [set color [255 ( number * 255) ( number * 255)]] [set color [( number * 255) ( number * 255) 255]]
  ifelse (number <= 0.5) [set color red + ( number * 9.99 )] [set color 114 - (number * 9.99) ]
end

to-report plus-or-minus [ value ] ;used in trait mutation to randomly increase or decrease the mutation-size
    ; randomly reports either +value or -value
    report value * (((random 2) * 2) - 1)
    ; explanation of "(((random 2) * 2) - 1)"
    ; Operation:    Yields:
    ; random 2   -> 0           or 1
    ;      * 2   -> 0 * 2 =  0  or 1 * 2 = 2
    ;      - 1   -> 0 - 1 = -1  or 2 - 1 = 1
    ; thus, returns -1 or +1
end
@#$#@#$#@
GRAPHICS-WINDOW
304
10
814
541
-1
-1
5.0
1
10
1
1
1
0
0
0
1
0
99
0
99
1
1
1
ticks
1000.0

BUTTON
15
9
78
42
setup
setup
NIL
1
T
OBSERVER
NIL
S
NIL
NIL
1

BUTTON
15
41
78
74
go
;ifelse ticks != 50000 [go][stop]\nifelse ticks != 100000 [go][stop]\n;go\n
T
1
T
OBSERVER
NIL
G
NIL
NIL
1

BUTTON
15
74
78
107
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
118
180
290
213
N
N
0
2000
500
100
1
NIL
HORIZONTAL

CHOOSER
118
12
281
57
mode
mode
"info" "radius"
0

CHOOSER
118
57
256
102
fmap
fmap
"2.001" "2.05" "2.10" "2.15" "2.20" "2.25" "2.30" "2.35" "2.40" "2.45" "2.50" "2.55" "2.60" "2.65" "2.70" "2.75" "2.80" "2.85" "2.90" "2.95" "2.99" "cone"
0

SLIDER
118
213
290
246
foresight
foresight
0
1
1
.05
1
NIL
HORIZONTAL

CHOOSER
118
135
256
180
maptype
maptype
"fitness" "ticks" "occfreq" "effit"
0

SLIDER
118
102
256
135
run#
run#
1
100
1
1
1
NIL
HORIZONTAL

SLIDER
814
10
984
43
birth-rate
birth-rate
0
1
0.1
0.1
1
NIL
HORIZONTAL

SLIDER
814
43
984
76
death-rate
death-rate
0
birth-rate
0.06
0.01
1
NIL
HORIZONTAL

SWITCH
15
140
105
173
colonize?
colonize?
0
1
-1000

SLIDER
118
246
290
279
copyrate
copyrate
0
1
0
0.05
1
NIL
HORIZONTAL

PLOT
3
509
244
629
Pop
ticks
Pop
0.0
10.0
0.0
10.0
true
false
"" ";ask agents [measure-total-distance]"
PENS
"Default" 1.0 0 -16777216 true "" "if plots-on? = TRUE [plotxy ticks count agents]"

MONITOR
244
509
294
554
Pop
count agents
0
1
11

PLOT
3
378
245
509
Trait
ticks
Trait
0.0
100000.0
0.0
1.0
true
false
"" ""
PENS
"Median" 100.0 0 -16777216 true "" ";plotxy ticks mean [acopyrate] of agents"

MONITOR
245
378
295
423
MedC
median [acopyrate] of agents
2
1
11

SLIDER
118
279
290
312
mutation-size
mutation-size
0.01
.5
0.1
0.01
1
NIL
HORIZONTAL

BUTTON
250
103
305
136
rand
set run# random 100 + 1
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
304
541
504
691
Effective fitness
NIL
NIL
0.0
100.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "clear-plot\nif plots-on? = TRUE [\nlet env 0\nwhile [env <= 100 AND ticks > 0][\n  set env env + 1\n  let patch-env patch-set patches with [elevation = env]\n  if any? patch-env [plotxy env mean [cum-effit] of patch-env ]\n  ]\n  ]"

SWITCH
15
206
105
239
randTrait?
randTrait?
0
1
-1000

SLIDER
118
311
290
344
mutation-rate
mutation-rate
0
.1
0.0010
.001
1
NIL
HORIZONTAL

SWITCH
15
239
105
272
plots-on?
plots-on?
1
1
-1000

MONITOR
245
423
295
468
MedR
median [fsdist] of agents
2
1
11

@#$#@#$#@
## WHAT IS IT?

Agent-based model extending an earlier model found here: http://www.openabm.org/model/3846/

The models are designed to connect a mechanism of local scale mobility, namely foraging, with the global scale phenomenon of population dispersal. This model adds to the ability of agents to acquire information about their environment, one individual and one social.

## HOW IT WORKS

See the earlier model for the basic description. There are two variations of the model here, "radius" and "info". In "radius", an agent trait fsdist, determines the radius of the resource assessment neighbourhood. They choose the highest resource cell out of these patches at probability "foresight", and move one step towards it if empty, or move randomly otherwise. The median trait value evolves over time through natural selection by the distribution of the spatial resource environment.

In "info", an agent trait copyrate, determines the probability of copying information about resources from another random agent, or moving randomly otherwise. When copying, agents move one step towards another agent if they occupy a higher resource cell. Again, the trait value evolves over the course of a run.

## HOW TO USE IT

Maps are not generated by NetLogo. Download the map set as well which (includes a bash script for generating your own with GRASS GIS). Unzip the surfeq folder into the same folder as this nlogo file.

Choose a heterogeneity value from the "fmap" list running from 2.001 (least heterogeneous) to 2.999 (most heterogenous). Click rand to choose 1 of the 100 randomly generated surfaces at the selected heterogeneity level. Optionally also adjust other initial parameters. Setup and Go to run.

See the BehaviourSpace dialog for the run sets used in the dissertation.

## THINGS TO NOTICE

Resource assessment radius and copyrate evolve to relatively low levels, especially for low heterogeneity landscapes. 

## CREDITS AND REFERENCES

Colin D. Wren wrote this model as a part of his PhD dissertation at McGill University.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.3
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="info fp" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>export-plot "Trait" (word "infoshare/screenshots/fp" fmap "_" run# ".csv")
display-elevation
export-view (word "infoshare/screenshots/fp" fmap "_" run# ".png")</final>
    <timeLimit steps="100000"/>
    <metric>nummap</metric>
    <metric>mean [elevation] of agents</metric>
    <metric>mean [acopyrate] of agents</metric>
    <metric>(word "screenshots/fp" fmap "_" run# ".csv")</metric>
    <metric>(word "screenshots/fp" fmap "_" run# ".png")</metric>
    <enumeratedValueSet variable="random-seed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maptype">
      <value value="&quot;fitness&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mode">
      <value value="&quot;info&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="run#" first="1" step="1" last="30"/>
    <enumeratedValueSet variable="fmap">
      <value value="&quot;2.001&quot;"/>
      <value value="&quot;2.99&quot;"/>
      <value value="&quot;2.20&quot;"/>
      <value value="&quot;2.40&quot;"/>
      <value value="&quot;2.60&quot;"/>
      <value value="&quot;2.80&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="colonize?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copyrate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="birth-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-size">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0010"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="info pp" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>export-plot "Trait" (word "infoshare/screenshots/pp" fmap "_" run# ".csv")
display-elevation
export-view (word "infoshare/screenshots/pp" fmap "_" run# ".png")</final>
    <timeLimit steps="100000"/>
    <exitCondition>count agents &lt;= 10</exitCondition>
    <metric>nummap</metric>
    <metric>count agents</metric>
    <metric>mean [elevation] of agents</metric>
    <metric>mean [acopyrate] of agents</metric>
    <metric>(word "screenshots/pp" fmap "_" run# ".csv")</metric>
    <metric>(word "screenshots/pp" fmap "_" run# ".png")</metric>
    <enumeratedValueSet variable="random-seed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maptype">
      <value value="&quot;fitness&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mode">
      <value value="&quot;info&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="run#" first="1" step="1" last="30"/>
    <enumeratedValueSet variable="fmap">
      <value value="&quot;2.001&quot;"/>
      <value value="&quot;2.99&quot;"/>
      <value value="&quot;2.20&quot;"/>
      <value value="&quot;2.40&quot;"/>
      <value value="&quot;2.60&quot;"/>
      <value value="&quot;2.80&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="colonize?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copyrate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="birth-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.06"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-size">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0010"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="info fp &gt; N" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>export-plot "Trait" (word "infoshare/screenshots/fixed" fmap "_" run# "_" N ".csv")</final>
    <timeLimit steps="100000"/>
    <metric>nummap</metric>
    <metric>mean [elevation] of agents</metric>
    <metric>mean [acopyrate] of agents</metric>
    <enumeratedValueSet variable="random-seed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="200"/>
      <value value="1000"/>
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maptype">
      <value value="&quot;fitness&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mode">
      <value value="&quot;info&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="run#" first="1" step="10" last="100"/>
    <enumeratedValueSet variable="fmap">
      <value value="&quot;2.001&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="birth-rate">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="colonize?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-size">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copyrate">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="radius pp" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>export-plot "Trait" (word "fsdist/screenshots/pp" fmap "_" run# "_" foresight ".csv")
display-elevation
export-view (word "fsdist/screenshots/pp" fmap "_" run# "_" foresight ".png")</final>
    <timeLimit steps="100000"/>
    <metric>nummap</metric>
    <metric>count agents</metric>
    <metric>mean [elevation] of agents</metric>
    <metric>mean [fsdist] of agents</metric>
    <metric>(word "screenshots/pp" fmap "_" run# "_" foresight ".csv")</metric>
    <metric>(word "screenshots/pp" fmap "_" run# "_" foresight ".png")</metric>
    <enumeratedValueSet variable="random-seed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maptype">
      <value value="&quot;fitness&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mode">
      <value value="&quot;radius&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="run#" first="1" step="1" last="30"/>
    <enumeratedValueSet variable="fmap">
      <value value="&quot;2.001&quot;"/>
      <value value="&quot;2.99&quot;"/>
      <value value="&quot;2.20&quot;"/>
      <value value="&quot;2.40&quot;"/>
      <value value="&quot;2.60&quot;"/>
      <value value="&quot;2.80&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foresight">
      <value value="0.25"/>
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="birth-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0.06"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-size">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0010"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="radius fp" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>export-plot "Trait" (word "fsdist/screenshots/fp" fmap "_" run# "_" foresight ".csv")
display-elevation
export-view (word "fsdist/screenshots/fp" fmap "_" run# "_" foresight ".png")</final>
    <timeLimit steps="100000"/>
    <metric>nummap</metric>
    <metric>mean [elevation] of agents</metric>
    <metric>mean [fsdist] of agents</metric>
    <metric>(word "screenshots/fp" fmap "_" run# "_" foresight ".csv")</metric>
    <metric>(word "screenshots/fp" fmap "_" run# "_" foresight ".png")</metric>
    <enumeratedValueSet variable="random-seed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maptype">
      <value value="&quot;fitness&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mode">
      <value value="&quot;radius&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="run#" first="1" step="1" last="30"/>
    <enumeratedValueSet variable="fmap">
      <value value="&quot;2.001&quot;"/>
      <value value="&quot;2.99&quot;"/>
      <value value="&quot;2.20&quot;"/>
      <value value="&quot;2.40&quot;"/>
      <value value="&quot;2.60&quot;"/>
      <value value="&quot;2.80&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foresight">
      <value value="0.25"/>
      <value value="0.75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="birth-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-size">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0010"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="radius fp &gt; N" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>export-plot "Trait" (word "fsdist/screenshots/fp" fmap "_" run# "_" foresight "_" N ".csv")</final>
    <timeLimit steps="100000"/>
    <metric>nummap</metric>
    <metric>mean [elevation] of agents</metric>
    <metric>mean [fsdist] of agents</metric>
    <enumeratedValueSet variable="random-seed">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="N">
      <value value="100"/>
      <value value="1000"/>
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maptype">
      <value value="&quot;fitness&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mode">
      <value value="&quot;radius&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="run#" first="1" step="10" last="100"/>
    <enumeratedValueSet variable="fmap">
      <value value="&quot;2.001&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foresight">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-size">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.0010"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="birth-rate">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-rate">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
